/* quartz_log.cc: A logfile for quartz.
 *
 * ----START-LICENCE----
 * Copyright 1999,2000,2001 BrightStation PLC
 * Copyright 2002 Ananova Ltd
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 * -----END-LICENCE-----
 */

#include <config.h>
#include "quartz_log.h"
#include "omdebug.h"

#include <string.h>
#include <errno.h>

QuartzLog::QuartzLog(std::string filename)
	: fp(0)
{
    DEBUGCALL(DB, void, "QuartzLog", filename);
    if (!filename.empty()) {
	fp = fopen(filename.c_str(), "a");
	if (fp == 0)
	    throw OmOpeningError("Can't open logfile `" + filename + "': " +
				 std::string(strerror(errno)));
    }
}

QuartzLog::~QuartzLog()
{
    DEBUGCALL(DB, void, "~QuartzLog", "");
    if (fp != 0) {
	(void) fclose(fp);
	// Would like to complain if there's an error, but mustn't because
	// we're in a destructor
    }
}
 
void
QuartzLog::make_entry(std::string entry) const
{
    DEBUGCALL(DB, void, "QuartzLog::make_entry", entry);
    if (fp != 0) {
	fwrite(entry.data(), entry.size(), 1, fp);
	putc('\n', fp);
	if (fflush(fp)) {
	    throw OmOpeningError("Error when flushing logfile: " +
				 std::string(strerror(errno)));
	}
    }
}

